/*
*/

#include <string>
#include <list>


class RTSMonFrame
{
private:
    /* data */
    int id;
    std::string name;
    int samplerate;
    int sampleperiod;
    int downtime;
    std::string status;
    std::list<std::string> items;

public:
    
   RTSMonFrame(int id, std::string name, int samplerate, int sampleperiod, int downtime, std::string status) {
    this->id = id;
    this->name = name;
    this->samplerate = samplerate;
    this->sampleperiod = sampleperiod;
    this->downtime = downtime;
    this->status = status;
   }
   
   RTSMonFrame(int id) {
    this->id = id;
   }

   RTSMonFrame(RTSMonFrame& rtsMonFrameCopy) {
    this->id = rtsMonFrameCopy.GetId();
   } 

   ~RTSMonFrame();

   void Add(std::string item){
    this->items.push_back(item);
   }
   int GetId() {
    return this->id;
   }

   std::string GetName() {
    return this->name;
   }
 
   int GetSampleRate() {
    return this->samplerate;
   }

   int GetSamplePeriod(){
    return this->sampleperiod;
   }
   
   int GetDownTime(){
    return this->downtime;
   }

   std::string Gettatus() {
    return this->status;
   }
   
   std::list<std::string>& GetItems() {
    return this->items;
   }

};
